@@ -100,6 +100,8 @@ class RestCall(Logger):
             #TODO Tell the user their URL was bad and try a different one
             self.error(f'TooManyRedirects while performing api request using: {url}')
         except exceptions.HTTPError as e:
+            if resp.status_code == 401:
+                raise PermissionError(u)
             self.error(e)
         except exceptions.RequestException as e:
             # catastrophic error. bail.
